# Generated file. Do not edit

[
          [
            'name',
            'Xorg::InputDevice::KeyboardOptModel::Xorg-it',
            'generated_by',
            'Config::Model Build.PL',
            'element',
            [],
            'description',
            []
          ]
        ]
