# Generated file. Do not edit

[
          [
            'name',
            'Xorg::ConfigDir',
            'generated_by',
            'Config::Model Build.PL',
            'config_dir',
            '/etc/X11'
          ]
        ]
